@@ -84,7 +84,7 @@ void ExpatTpmParser::GetFiles(const XML_Char* text, vector<string>& files)
 #if defined(MIKTEX_UNIX)
     path.ConvertToUnix();
 #endif
-    if (texMFPrefix.empty() || (PathName::Compare(texMFPrefix, path, texMFPrefix.length()) == 0))
+    if (texMFPrefix.empty() || (PathName::Compare(PathName(texMFPrefix), path, texMFPrefix.length()) == 0))
     {
       files.push_back(path.ToString());
     }
@@ -274,7 +274,7 @@ void ExpatTpmParser::OnEndElement(void* pv, const XML_Char* name)
       bool haveManifestFile = false;
       for (const auto& file : This->packageInfo.runFiles)
       {
-        if (PathName::Compare(file, manifestFile) == 0)
+        if (PathName::Compare(PathName(file), manifestFile) == 0)
         {
           haveManifestFile = true;
           break;
