@@ -55,7 +55,7 @@ PackageDataStore::PackageDataStore() :
 {
 }
 
-void PackageDataStore::LoadAllPackageManifests(const PathName& packageManifestsPath)
+void PackageDataStore::LoadAllPackageManifests(const PathName& packageManifestsPath, bool mustBeSigned)
 {
   trace_mpm->WriteLine(TRACE_FACILITY, fmt::format(T_("loading all package manifests ({0})"), Q_(packageManifestsPath)));
 
@@ -66,7 +66,7 @@ void PackageDataStore::LoadAllPackageManifests(const PathName& packageManifestsP
   }
 
   unique_ptr<Cfg> cfg = Cfg::Create();
-  cfg->Read(packageManifestsPath);
+  cfg->Read(packageManifestsPath, mustBeSigned);
 
   Load(*cfg);
 
@@ -194,12 +194,12 @@ unsigned long PackageDataStore::DecrementFileRefCount(const PathName& path)
 
 void PackageDataStore::NeedPackageManifestsIni()
 {
-  PathName existingPackageManifestsIni = session->GetSpecialPath(SpecialPath::InstallRoot) / MIKTEX_PATH_PACKAGE_MANIFESTS_INI;
+  PathName existingPackageManifestsIni = session->GetSpecialPath(SpecialPath::InstallRoot) / PathName(MIKTEX_PATH_PACKAGE_MANIFESTS_INI);
   if (File::Exists(existingPackageManifestsIni))
   {
     return;
   }
-  PathName tpmDir = session->GetSpecialPath(SpecialPath::InstallRoot) / MIKTEX_PATH_PACKAGE_MANIFEST_DIR;
+  PathName tpmDir = session->GetSpecialPath(SpecialPath::InstallRoot) / PathName(MIKTEX_PATH_PACKAGE_MANIFEST_DIR);
   if (Directory::Exists(tpmDir))
   {
     trace_mpm->WriteLine(TRACE_FACILITY, TraceLevel::Info, fmt::format("starting migration: {} -> {}", tpmDir, existingPackageManifestsIni));
@@ -237,13 +237,13 @@ PackageDataStore& PackageDataStore::Load()
   unique_ptr<Cfg> cfg = Cfg::Create();
   if (!session->IsAdminMode())
   {
-    PathName userPath = session->GetSpecialPath(SpecialPath::UserInstallRoot) / MIKTEX_PATH_PACKAGE_MANIFESTS_INI;
+    PathName userPath = session->GetSpecialPath(SpecialPath::UserInstallRoot) / PathName(MIKTEX_PATH_PACKAGE_MANIFESTS_INI);
     if (File::Exists(userPath))
     {
       cfg->Read(userPath);
     }
   }
-  PathName commonPath = session->GetSpecialPath(SpecialPath::CommonInstallRoot) / MIKTEX_PATH_PACKAGE_MANIFESTS_INI;
+  PathName commonPath = session->GetSpecialPath(SpecialPath::CommonInstallRoot) / PathName(MIKTEX_PATH_PACKAGE_MANIFESTS_INI);
   if ((session->IsAdminMode() || session->GetSpecialPath(SpecialPath::UserInstallRoot).Canonicalize() != session->GetSpecialPath(SpecialPath::CommonInstallRoot).Canonicalize()) && File::Exists(commonPath))
   {
     cfg->SetOptions({ Cfg::Option::NoOverwriteKeys });
@@ -381,8 +381,8 @@ void PackageDataStore::LoadVarData()
   if (!comboCfg.Loaded())
   {
     comboCfg.Load(
-      session->IsAdminMode() ? "" : session->GetSpecialPath(SpecialPath::UserInstallRoot) / MIKTEX_PATH_PACKAGES_INI,
-      session->GetSpecialPath(SpecialPath::CommonInstallRoot) / MIKTEX_PATH_PACKAGES_INI);
+      session->IsAdminMode() ? PathName() : session->GetSpecialPath(SpecialPath::UserInstallRoot) / PathName(MIKTEX_PATH_PACKAGES_INI),
+      session->GetSpecialPath(SpecialPath::CommonInstallRoot) / PathName(MIKTEX_PATH_PACKAGES_INI));
   }
 }
 
