@@ -31,8 +31,6 @@
 #include <string>
 #include <vector>
 
-#include <miktex/App/Application>
-
 #include <miktex/C4P/C4P>
 
 #include <miktex/Core/Exceptions>
@@ -137,7 +135,7 @@ public:
   MIKTEXMFTHISAPI(void) Finalize() override;
 
 public:
-  MIKTEXMFTHISAPI(void) SetProgramInfo(const std::string& programName, const std::string& version, const std::string& copyright, const std::string& trademarks);
+  MIKTEXMFTHISAPI(void) SetProgram(C4P::ProgramBase* program, const std::string& programName, const std::string& version, const std::string& copyright, const std::string& trademarks);
 
 public:
   virtual MIKTEXMFTHISAPI(std::string) TheNameOfTheGame() const;
@@ -257,6 +255,9 @@ public:
 public:
   MIKTEXMFTHISAPI(bool) GetVerboseFlag() const;
 
+public:
+  MIKTEXMFTHISAPI(C4P::ProgramBase*) GetProgram() const;
+
 private:
   class impl;
   std::unique_ptr<impl> pimpl;
@@ -295,7 +296,7 @@ inline void miktexprocesscommandlineoptions()
 template<class PROGRAM_CLASS, class WEBAPP_CLASS> class ProgramRunner
 {
 public:
-  int Run(PROGRAM_CLASS& prog, WEBAPP_CLASS& app, const std::string& programName, int argc, char* argv[])
+  int Run(PROGRAM_CLASS& prog, WEBAPP_CLASS& app, const std::string& progName, int argc, char* argv[])
   {
     std::string componentVersion;
 #if defined(MIKTEX_COMPONENT_VERSION_STR)
@@ -309,7 +310,8 @@ public:
 #if defined(MIKTEX_COMP_TM_STR)
     componentTrademark = MIKTEX_COMP_TM_STR;
 #endif
-    app.SetProgramInfo(programName, componentVersion, componentCopyright, componentTrademark);
+    app.SetProgram(&prog, progName, componentVersion, componentCopyright, componentTrademark);
+    prog.SetParent(&app);
     try
     {
       MIKTEX_ASSERT(argv != nullptr && argv[argc] == nullptr);
