@@ -1,5 +1,5 @@
 /*****
- * drawbezierpatch.cc
+ * bezierpatch.cc
  * Authors: John C. Bowman and Jesse Frohlich
  *
  * Render Bezier patches and triangles.
@@ -13,31 +13,20 @@ namespace camp {
 using ::orient2d;
 using ::orient3d;
 
-size_t tstride;
-
-double viewpoint[3];
-
 #ifdef HAVE_GL
 
-std::vector<GLfloat> BezierPatch::buffer;
-std::vector<GLfloat> BezierPatch::Buffer;
-std::vector<GLuint> BezierPatch::indices;
-std::vector<GLuint> BezierPatch::Indices;
-std::vector<GLfloat> BezierPatch::tbuffer;
-std::vector<GLuint> BezierPatch::tindices;
-std::vector<GLfloat> BezierPatch::tBuffer;
-std::vector<GLuint> BezierPatch::tIndices;
+int MaterialIndex;
 
-std::vector<GLuint>& I=BezierPatch::tIndices;
-std::vector<GLfloat>& V=BezierPatch::tBuffer;
+//std::vector<GLuint>& I=transparentData.Indices;
+//std::vector<VertexData>& V=transparentData.Vertices;
 bool colors;
 
 std::vector<GLfloat> zbuffer;
 std::vector<GLfloat> xbuffer;
 std::vector<GLfloat> ybuffer;
 
-std::vector<GLfloat> xmin,ymin,zmin;
-std::vector<GLfloat> xmax,ymax,zmax;
+//std::vector<GLfloat> xmin,ymin,zmin;
+//std::vector<GLfloat> xmax,ymax,zmax;
 std::vector<GLfloat> zsum;
 
 inline double min(double a, double b, double c)
@@ -63,15 +52,7 @@ struct iz {
 
 std::vector<iz> IZ;
 
-GLuint BezierPatch::nvertices=0;
-GLuint BezierPatch::ntvertices=0;
-GLuint BezierPatch::Nvertices=0;
-GLuint BezierPatch::Ntvertices=0;
-
-extern const double Fuzz2;
-
 const double FillFactor=0.1;
-const double BezierFactor=0.4;
 
 inline int sgn1(double x) 
 {
@@ -180,23 +161,8 @@ inline triple interp(const triple& a, const triple& b, double t)
   return a+(b-a)*t;
 }
 
-inline void cross(double *dest, const double *u, const double *v,
-                  const double *w)
-{
-  double u0=u[0]-w[0];
-  double u1=u[1]-w[1];
-  double u2=u[2]-w[2];
-  double v0=v[0]-w[0];
-  double v1=v[1]-w[1];
-  double v2=v[2]-w[2];
-  dest[0]=u1*v2-u2*v1;
-  dest[1]=u2*v0-u0*v2;
-  dest[2]=u0*v1-u1*v0;
-}
-
 unsigned n;
 unsigned int count;
-const size_t nbuffer=10000;
   
 // Sort nonintersecting triangles by depth.
 int compare(const void *p, const void *P)
@@ -249,6 +215,7 @@ int compare(const void *p, const void *P)
   */
 }
 
+#if 0
 void split(unsigned i3, GLuint ia, GLuint ib, GLuint ic,
            double *a, double *b, double *c, double *N, double *A) {
   double td=intersect(a,b,N,A);
@@ -279,11 +246,11 @@ void split(unsigned i3, GLuint ia, GLuint ib, GLuint ic,
     interp(cd,ca,cb,td);
     interp(ce,ca,cc,te);
         
-    id=BezierPatch::tVertex(d,nd,cd);
-    ie=BezierPatch::tVertex(e,ne,ce);
+    id=data.Vertex(d,nd,cd);
+    ie=data.Vertex(e,ne,ce);
   } else {
-    id=BezierPatch::tvertex(d,nd);
-    ie=BezierPatch::tvertex(e,ne);
+    id=data.Vertex(d,nd);
+    ie=data.Vertex(e,ne);
   }
       
   I[i3]=ia;
@@ -298,42 +265,97 @@ void split(unsigned i3, GLuint ia, GLuint ib, GLuint ic,
   I.push_back(ib);
   I.push_back(ic);
 }
+#endif
 
-void BezierPatch::init(double res, const triple& Min, const triple& Max,
-                       bool transparent, GLfloat *colors)
+void BezierPatch::init(double res)
 {
   res2=res*res;
-  Res2=BezierFactor*BezierFactor*res2;
   Epsilon=FillFactor*res;
-  this->Min=Min;
-  this->Max=Max;
+
+  MaterialIndex=transparent ?
+    (color ? -1-materialIndex : 1+materialIndex) : materialIndex;
   
-  const size_t nbuffer=10000;
-  indices.reserve(nbuffer);
-  if(transparent) {
-    tbuffer.reserve(nbuffer);
-    tindices.reserve(nbuffer);
-    pindices=&tindices;
-    pvertex=&tvertex;
-    if(colors) {
-      tBuffer.reserve(nbuffer);
-      tIndices.reserve(nbuffer);
-      pindices=&tIndices;
-      pVertex=&tVertex;
-    }
-  } else {
-    buffer.reserve(nbuffer);
-    pindices=&indices;
-    pvertex=&vertex;
-    if(colors) {
-      Buffer.reserve(nbuffer);
-      Indices.reserve(nbuffer);
-      pindices=&Indices;
-      pVertex=&Vertex;
-    }
-  }
+  pvertex=transparent ? &vertexBuffer::tvertex : &vertexBuffer::vertex;
 }
     
+void BezierPatch::render(const triple *p, bool straight, GLfloat *c0)
+{
+  triple p0=p[0];
+  epsilon=0;
+  for(unsigned i=1; i < 16; ++i)
+    epsilon=max(epsilon,abs2(p[i]-p0));
+  epsilon *= DBL_EPSILON;
+    
+  triple p3=p[3];
+  triple p12=p[12];
+  triple p15=p[15];
+
+  triple n0=normal(p3,p[2],p[1],p0,p[4],p[8],p12);
+  if(abs2(n0) <= epsilon) {
+    n0=normal(p3,p[2],p[1],p0,p[13],p[14],p15);
+    if(abs2(n0) <= epsilon) n0=normal(p15,p[11],p[7],p3,p[4],p[8],p12);
+  }
+  
+  triple n1=normal(p0,p[4],p[8],p12,p[13],p[14],p15);
+  if(abs2(n1) <= epsilon) {
+    n1=normal(p0,p[4],p[8],p12,p[11],p[7],p3);
+    if(abs2(n1) <= epsilon) n1=normal(p3,p[2],p[1],p0,p[13],p[14],p15);
+  }
+    
+  triple n2=normal(p12,p[13],p[14],p15,p[11],p[7],p3);
+  if(abs2(n2) <= epsilon) {
+    n2=normal(p12,p[13],p[14],p15,p[2],p[1],p0);
+    if(abs2(n2) <= epsilon) n2=normal(p0,p[4],p[8],p12,p[11],p[7],p3);
+  }
+    
+  triple n3=normal(p15,p[11],p[7],p3,p[2],p[1],p0);
+  if(abs2(n3) <= epsilon) {
+    n3=normal(p15,p[11],p[7],p3,p[4],p[8],p12);
+    if(abs2(n3) <= epsilon) n3=normal(p12,p[13],p[14],p15,p[2],p[1],p0);
+  }
+    
+  GLuint i0,i1,i2,i3;
+  if(color) {
+    GLfloat *c1=c0+4;
+    GLfloat *c2=c0+8;
+    GLfloat *c3=c0+12;
+    
+    i0=data.Vertex(p0,n0,c0);
+    i1=data.Vertex(p12,n1,c1);
+    i2=data.Vertex(p15,n2,c2);
+    i3=data.Vertex(p3,n3,c3);
+      
+    if(!straight)
+      render(p,i0,i1,i2,i3,p0,p12,p15,p3,false,false,false,false,
+             c0,c1,c2,c3);
+  } else {
+    i0=(data.*pvertex)(p0,n0);
+    i1=(data.*pvertex)(p12,n1);
+    i2=(data.*pvertex)(p15,n2);
+    i3=(data.*pvertex)(p3,n3);
+    
+    if(!straight)
+      render(p,i0,i1,i2,i3,p0,p12,p15,p3,false,false,false,false);
+  }
+    
+  if(straight) {
+    std::vector<GLuint> &q=data.indices;
+    triple Pa[]={p0,p12,p15};
+    if(!offscreen(3,Pa)) {
+      q.push_back(i0);
+      q.push_back(i1);
+      q.push_back(i2);
+    }
+    triple Pb[]={p0,p15,p3};
+    if(!offscreen(3,Pb)) {
+      q.push_back(i0);
+      q.push_back(i2);
+      q.push_back(i3);
+    }
+  }
+  append();
+}
+
 // Use a uniform partition to draw a Bezier patch.
 // p is an array of 16 triples representing the control points.
 // Pi are the (possibly) adjusted vertices indexed by Ii.
@@ -344,27 +366,31 @@ void BezierPatch::render(const triple *p,
                          bool flat0, bool flat1, bool flat2, bool flat3,
                          GLfloat *C0, GLfloat *C1, GLfloat *C2, GLfloat *C3)
 {
-  if(Distance(p) < res2) { // Patch is flat
-    triple P[]={P0,P1,P2,P3};
-    if(!offscreen(4,P)) {
-      std::vector<GLuint> &p=*pindices;
-      p.push_back(I0);
-      p.push_back(I1);
-      p.push_back(I2);
-      p.push_back(I0);
-      p.push_back(I2);
-      p.push_back(I3);
+  pair d=Distance(p);
+  if(d.getx() < res2 && d.gety() < res2) { // Bezier patch is flat
+    triple Pa[]={P0,P1,P2};
+    std::vector<GLuint> &q=data.indices;
+    if(!offscreen(3,Pa)) {
+      q.push_back(I0);
+      q.push_back(I1);
+      q.push_back(I2);
+    }
+    triple Pb[]={P0,P2,P3};
+    if(!offscreen(3,Pb)) {
+      q.push_back(I0);
+      q.push_back(I2);
+      q.push_back(I3);
     }
   } else { // Patch is not flat
-    if(offscreen(16,p)) return;
-    /* Control points are indexed as follows:
-         
+   if(offscreen(16,p)) return;
+
+   /* Control points are indexed as follows:
+
        Coordinate
        +-----
         Index
          
-
-       03    13    23    33
+        03    13    23    33
        +-----+-----+-----+
        |3    |7    |11   |15
        |     |     |     |
@@ -378,22 +404,209 @@ void BezierPatch::render(const triple *p,
        |     |     |     |
        |00   |10   |20   |30
        +-----+-----+-----+
-       0     4     8     12
-         
+        0     4     8     12
 
-       Subdivision:
+   */
+
+    triple p0=p[0];
+    triple p3=p[3];
+    triple p12=p[12];
+    triple p15=p[15];
+
+   if(d.getx() < res2) { // flat in horizontal direction; split vertically
+     /*
+       P refers to a corner
+       m refers to a midpoint
+       s refers to a subpatch
+
+       +--------+--------+
+       |P3             P2|
+       |                 |
+       |       s1        |
+       |                 |
+       |                 |
+    m1 +-----------------+ m0
+       |                 |
+       |                 |
+       |       s0        |
+       |                 |
+       |P0             P1|
+       +-----------------+
+
+     */
+
+     Split3 c0(p0,p[1],p[2],p3);
+     Split3 c1(p[4],p[5],p[6],p[7]);
+     Split3 c2(p[8],p[9],p[10],p[11]);
+     Split3 c3(p12,p[13],p[14],p15);
+
+     triple s0[]={p0  ,c0.m0,c0.m3,c0.m5,
+                  p[4],c1.m0,c1.m3,c1.m5,
+                  p[8],c2.m0,c2.m3,c2.m5,
+                  p12 ,c3.m0,c3.m3,c3.m5};
+
+     triple s1[]={c0.m5,c0.m4,c0.m2,p3,
+                  c1.m5,c1.m4,c1.m2,p[7],
+                  c2.m5,c2.m4,c2.m2,p[11],
+                  c3.m5,c3.m4,c3.m2,p15};
+
+     triple n0=normal(s0[12],s0[13],s0[14],s0[15],s0[11],s0[7],s0[3]);
+     if(abs2(n0) <= epsilon) {
+       n0=normal(s0[12],s0[13],s0[14],s0[15],s0[2],s0[1],s0[0]);
+       if(abs2(n0) <= epsilon)
+         n0=normal(s0[0],s0[4],s0[8],s0[12],s0[11],s0[7],s0[3]);
+     }
+
+     triple n1=normal(s1[3],s1[2],s1[1],s1[0],s1[4],s1[8],s1[12]);
+     if(abs2(n1) <= epsilon) {
+       n1=normal(s1[3],s1[2],s1[1],s1[0],s1[13],s1[14],s1[15]);
+       if(abs2(n1) <= epsilon)
+         n1=normal(s1[15],s1[11],s1[7],s1[3],s1[4],s1[8],s1[12]);
+     }
+
+     // A kludge to remove subdivision cracks, only applied the first time
+     // an edge is found to be flat before the rest of the subpatch is.
+
+     triple m0=0.5*(P1+P2);
+     if(!flat1) {
+       if((flat1=Straightness(p12,p[13],p[14],p15) < res2))
+         m0 -= Epsilon*unit(differential(s1[12],s1[8],s1[4],s1[0]));
+       else m0=s0[15];
+     }
+
+     triple m1=0.5*(P3+P0);
+     if(!flat3) {
+       if((flat3=Straightness(p0,p[1],p[2],p3) < res2))
+         m1 -= Epsilon*unit(differential(s0[3],s0[7],s0[11],s0[15]));
+       else m1=s1[0];
+     }
+
+     if(color) {
+       GLfloat c0[4],c1[4];
+       for(size_t i=0; i < 4; ++i) {
+         c0[i]=0.5*(C1[i]+C2[i]);
+         c1[i]=0.5*(C3[i]+C0[i]);
+       }
+
+       GLuint i0=data.Vertex(m0,n0,c0);
+       GLuint i1=data.Vertex(m1,n1,c1);
+
+       render(s0,I0,I1,i0,i1,P0,P1,m0,m1,flat0,flat1,false,flat3,C0,C1,c0,c1);
+       render(s1,i1,i0,I2,I3,m1,m0,P2,P3,false,flat1,flat2,flat3,c1,c0,C2,C3);
+     } else {
+       GLuint i0=(data.*pvertex)(m0,n0);
+       GLuint i1=(data.*pvertex)(m1,n1);
+
+       render(s0,I0,I1,i0,i1,P0,P1,m0,m1,flat0,flat1,false,flat3);
+       render(s1,i1,i0,I2,I3,m1,m0,P2,P3,false,flat1,flat2,flat3);
+     }
+     return;
+   }
+   if(d.gety() < res2) { // flat in vertical direction; split horizontally
+     /*
        P refers to a corner
        m refers to a midpoint
        s refers to a subpatch
          
+                m1
+       +--------+--------+
+       |P3      |      P2|
+       |        |        |
+       |        |        |
+       |        |        |
+       |        |        |
+       |   s0   |   s1   |
+       |        |        |
+       |        |        |
+       |        |        |
+       |        |        |
+       |P0      |      P1|
+       +--------+--------+
+                m0
+
+     */
+
+     Split3 c0(p0,p[4],p[8],p12);
+     Split3 c1(p[1],p[5],p[9],p[13]);
+     Split3 c2(p[2],p[6],p[10],p[14]);
+     Split3 c3(p3,p[7],p[11],p15);
+
+     triple s0[]={p0,p[1],p[2],p3,
+                  c0.m0,c1.m0,c2.m0,c3.m0,
+                  c0.m3,c1.m3,c2.m3,c3.m3,
+                  c0.m5,c1.m5,c2.m5,c3.m5};
+
+     triple s1[]={c0.m5,c1.m5,c2.m5,c3.m5,
+                  c0.m4,c1.m4,c2.m4,c3.m4,
+                  c0.m2,c1.m2,c2.m2,c3.m2,
+                  p12,p[13],p[14],p15};
+
+     triple n0=normal(s0[0],s0[4],s0[8],s0[12],s0[13],s0[14],s0[15]);
+     if(abs2(n0) <= epsilon) {
+       n0=normal(s0[0],s0[4],s0[8],s0[12],s0[11],s0[7],s0[3]);
+       if(abs2(n0) <= epsilon)
+         n0=normal(s0[3],s0[2],s0[1],s0[0],s0[13],s0[14],s0[15]);
+     }
+
+     triple n1=normal(s1[15],s1[11],s1[7],s1[3],s1[2],s1[1],s1[0]);
+     if(abs2(n1) <= epsilon) {
+       n1=normal(s1[15],s1[11],s1[7],s1[3],s1[4],s1[8],s1[12]);
+       if(abs2(n1) <= epsilon)
+         n1=normal(s1[12],s1[13],s1[14],s1[15],s1[2],s1[1],s1[0]);
+     }
+
+     // A kludge to remove subdivision cracks, only applied the first time
+     // an edge is found to be flat before the rest of the subpatch is.
+
+     triple m0=0.5*(P0+P1);
+     if(!flat0) {
+       if((flat0=Straightness(p0,p[4],p[8],p12) < res2))
+         m0 -= Epsilon*unit(differential(s1[0],s1[1],s1[2],s1[3]));
+       else m0=s0[12];
+     }
+
+     triple m1=0.5*(P2+P3);
+     if(!flat2) {
+       if((flat2=Straightness(p15,p[11],p[7],p3) < res2))
+         m1 -= Epsilon*unit(differential(s0[15],s0[14],s0[13],s0[12]));
+       else m1=s1[3];
+     }
+
+     if(color) {
+       GLfloat c0[4],c1[4];
+       for(size_t i=0; i < 4; ++i) {
+         c0[i]=0.5*(C0[i]+C1[i]);
+         c1[i]=0.5*(C2[i]+C3[i]);
+       }
+
+       GLuint i0=data.Vertex(m0,n0,c0);
+       GLuint i1=data.Vertex(m1,n1,c1);
+
+       render(s0,I0,i0,i1,I3,P0,m0,m1,P3,flat0,false,flat2,flat3,C0,c0,c1,C3);
+       render(s1,i0,I1,I2,i1,m0,P1,P2,m1,flat0,flat1,flat2,false,c0,C1,C2,c1);
+     } else {
+       GLuint i0=(data.*pvertex)(m0,n0);
+       GLuint i1=(data.*pvertex)(m1,n1);
+
+       render(s0,I0,i0,i1,I3,P0,m0,m1,P3,flat0,false,flat2,flat3);
+       render(s1,i0,I1,I2,i1,m0,P1,P2,m1,flat0,flat1,flat2,false);
+     }
+     return;
+   }
+   /*
+       Horizontal and vertical subdivision:
+       P refers to a corner
+       m refers to a midpoint
+       s refers to a subpatch
+
                 m2
        +--------+--------+
        |P3      |      P2|
        |        |        |
        |   s3   |   s2   |
        |        |        |
-       |        |m4      |
-     m3+--------+--------+m1
+       |        | m4     |
+    m3 +--------+--------+ m1
        |        |        |
        |        |        |
        |   s0   |   s1   |
@@ -404,11 +617,6 @@ void BezierPatch::render(const triple *p,
     */
     
     // Subdivide patch:
-    triple p0=p[0];
-    triple p3=p[3];
-    triple p12=p[12];
-    triple p15=p[15];
-      
     Split3 c0(p0,p[1],p[2],p3);
     Split3 c1(p[4],p[5],p[6],p[7]);
     Split3 c2(p[8],p[9],p[10],p[11]);
@@ -434,27 +642,31 @@ void BezierPatch::render(const triple *p,
     triple m4=s0[15];
       
     triple n0=normal(s0[0],s0[4],s0[8],s0[12],s0[13],s0[14],s0[15]);
-    if(n0 == 0.0) {
+    if(abs2(n0) <= epsilon) {
       n0=normal(s0[0],s0[4],s0[8],s0[12],s0[11],s0[7],s0[3]);
-      if(n0 == 0.0) n0=normal(s0[3],s0[2],s0[1],s0[0],s0[13],s0[14],s0[15]);
+      if(abs2(n0) <= epsilon)
+        n0=normal(s0[3],s0[2],s0[1],s0[0],s0[13],s0[14],s0[15]);
     }
       
     triple n1=normal(s1[12],s1[13],s1[14],s1[15],s1[11],s1[7],s1[3]);
-    if(n1 == 0.0) {
+    if(abs2(n1) <= epsilon) {
       n1=normal(s1[12],s1[13],s1[14],s1[15],s1[2],s1[1],s1[0]);
-      if(n1 == 0.0) n1=normal(s1[0],s1[4],s1[8],s1[12],s1[11],s1[7],s1[3]);
+      if(abs2(n1) <= epsilon)
+        n1=normal(s1[0],s1[4],s1[8],s1[12],s1[11],s1[7],s1[3]);
     }
       
     triple n2=normal(s2[15],s2[11],s2[7],s2[3],s2[2],s2[1],s2[0]);
-    if(n2 == 0.0) {
+    if(abs2(n2) <= epsilon) {
       n2=normal(s2[15],s2[11],s2[7],s2[3],s2[4],s2[8],s2[12]);
-      if(n2 == 0.0) n2=normal(s2[12],s2[13],s2[14],s2[15],s2[2],s2[1],s2[0]);
+      if(abs2(n2) <= epsilon)
+        n2=normal(s2[12],s2[13],s2[14],s2[15],s2[2],s2[1],s2[0]);
     }
       
     triple n3=normal(s3[3],s3[2],s3[1],s3[0],s3[4],s3[8],s3[12]);
-    if(n3 == 0.0) {
+    if(abs2(n3) <= epsilon) {
       n3=normal(s3[3],s3[2],s3[1],s3[0],s3[13],s3[14],s3[15]);
-      if(n3 == 0.0) n3=normal(s3[15],s3[11],s3[7],s3[3],s3[4],s3[8],s3[12]);
+      if(abs2(n3) <= epsilon)
+        n3=normal(s3[15],s3[11],s3[7],s3[3],s3[4],s3[8],s3[12]);
     }
       
     triple n4=normal(s2[3],s2[2],s2[1],m4,s2[4],s2[8],s2[12]);
@@ -465,32 +677,32 @@ void BezierPatch::render(const triple *p,
     triple m0=0.5*(P0+P1);
     if(!flat0) {
       if((flat0=Straightness(p0,p[4],p[8],p12) < res2))
-        m0 -= Epsilon*unit(derivative(s1[0],s1[1],s1[2],s1[3]));
+        m0 -= Epsilon*unit(differential(s1[0],s1[1],s1[2],s1[3]));
       else m0=s0[12];
     }
       
     triple m1=0.5*(P1+P2);
     if(!flat1) {
       if((flat1=Straightness(p12,p[13],p[14],p15) < res2))
-        m1 -= Epsilon*unit(derivative(s2[12],s2[8],s2[4],s2[0]));
+        m1 -= Epsilon*unit(differential(s2[12],s2[8],s2[4],s2[0]));
       else m1=s1[15];
     }
       
     triple m2=0.5*(P2+P3);
     if(!flat2) {
       if((flat2=Straightness(p15,p[11],p[7],p3) < res2))
-        m2 -= Epsilon*unit(derivative(s3[15],s2[14],s2[13],s1[12]));
+        m2 -= Epsilon*unit(differential(s3[15],s3[14],s3[13],s3[12]));
       else m2=s2[3];
     }
       
     triple m3=0.5*(P3+P0);
     if(!flat3) {
       if((flat3=Straightness(p0,p[1],p[2],p3) < res2))
-        m3 -= Epsilon*unit(derivative(s0[3],s0[7],s0[11],s0[15]));
+        m3 -= Epsilon*unit(differential(s0[3],s0[7],s0[11],s0[15]));
       else m3=s3[0];
     }
       
-    if(C0) {
+    if(color) {
       GLfloat c0[4],c1[4],c2[4],c3[4],c4[4];
       for(size_t i=0; i < 4; ++i) {
         c0[i]=0.5*(C0[i]+C1[i]);
@@ -500,25 +712,23 @@ void BezierPatch::render(const triple *p,
         c4[i]=0.5*(c0[i]+c2[i]);
       }
       
-      GLuint i0=pVertex(m0,n0,c0);
-      GLuint i1=pVertex(m1,n1,c1);
-      GLuint i2=pVertex(m2,n2,c2);
-      GLuint i3=pVertex(m3,n3,c3);
-      GLuint i4=pVertex(m4,n4,c4);
-      render(s0,I0,i0,i4,i3,P0,m0,m4,m3,flat0,false,false,flat3,
-             C0,c0,c4,c3);
-      render(s1,i0,I1,i1,i4,m0,P1,m1,m4,flat0,flat1,false,false,
-             c0,C1,c1,c4);
-      render(s2,i4,i1,I2,i2,m4,m1,P2,m2,false,flat1,flat2,false,
-             c4,c1,C2,c2);
-      render(s3,i3,i4,i2,I3,m3,m4,m2,P3,false,false,flat2,flat3,
-             c3,c4,c2,C3);
+      GLuint i0=data.Vertex(m0,n0,c0);
+      GLuint i1=data.Vertex(m1,n1,c1);
+      GLuint i2=data.Vertex(m2,n2,c2);
+      GLuint i3=data.Vertex(m3,n3,c3);
+      GLuint i4=data.Vertex(m4,n4,c4);
+      
+      render(s0,I0,i0,i4,i3,P0,m0,m4,m3,flat0,false,false,flat3,C0,c0,c4,c3);
+      render(s1,i0,I1,i1,i4,m0,P1,m1,m4,flat0,flat1,false,false,c0,C1,c1,c4);
+      render(s2,i4,i1,I2,i2,m4,m1,P2,m2,false,flat1,flat2,false,c4,c1,C2,c2);
+      render(s3,i3,i4,i2,I3,m3,m4,m2,P3,false,false,flat2,flat3,c3,c4,c2,C3);
     } else {
-      GLuint i0=pvertex(m0,n0);
-      GLuint i1=pvertex(m1,n1);
-      GLuint i2=pvertex(m2,n2);
-      GLuint i3=pvertex(m3,n3);
-      GLuint i4=pvertex(m4,n4);
+      GLuint i0=(data.*pvertex)(m0,n0);
+      GLuint i1=(data.*pvertex)(m1,n1);
+      GLuint i2=(data.*pvertex)(m2,n2);
+      GLuint i3=(data.*pvertex)(m3,n3);
+      GLuint i4=(data.*pvertex)(m4,n4);
+      
       render(s0,I0,i0,i4,i3,P0,m0,m4,m3,flat0,false,false,flat3);
       render(s1,i0,I1,i1,i4,m0,P1,m1,m4,flat0,flat1,false,false);
       render(s2,i4,i1,I2,i2,m4,m1,P2,m2,false,flat1,flat2,false);
@@ -527,68 +737,52 @@ void BezierPatch::render(const triple *p,
   }
 }
 
-void BezierPatch::render(const triple *p, bool straight, GLfloat *c0)
+void BezierTriangle::render(const triple *p, bool straight, GLfloat *c0)
 {
   triple p0=p[0];
   epsilon=0;
-  for(unsigned i=1; i < 16; ++i)
+  for(int i=1; i < 10; ++i)
     epsilon=max(epsilon,abs2(p[i]-p0));
   
-  epsilon *= Fuzz2;
+  epsilon *= DBL_EPSILON;
     
-  triple p3=p[3];
-  triple p12=p[12];
-  triple p15=p[15];
-
-  triple n0=normal(p3,p[2],p[1],p0,p[4],p[8],p12);
-  if(n0 == 0.0) n0=normal(p3,p[2],p[1],p0,p[13],p[14],p15);
-  if(n0 == 0.0) n0=normal(p15,p[11],p[7],p3,p[4],p[8],p12);
+  triple p6=p[6];
+  triple p9=p[9];
     
-  triple n1=normal(p0,p[4],p[8],p12,p[13],p[14],p15);
-  if(n1 == 0.0) n1=normal(p0,p[4],p[8],p12,p[11],p[7],p3);
-  if(n1 == 0.0) n1=normal(p3,p[2],p[1],p0,p[13],p[14],p15);
+  triple n0=normal(p9,p[5],p[2],p0,p[1],p[3],p6);
+  triple n1=normal(p0,p[1],p[3],p6,p[7],p[8],p9);    
+  triple n2=normal(p6,p[7],p[8],p9,p[5],p[2],p0);
     
-  triple n2=normal(p12,p[13],p[14],p15,p[11],p[7],p3);
-  if(n2 == 0.0) n2=normal(p12,p[13],p[14],p15,p[2],p[1],p0);
-  if(n2 == 0.0) n2=normal(p0,p[4],p[8],p12,p[11],p[7],p3);
-    
-  triple n3=normal(p15,p[11],p[7],p3,p[2],p[1],p0);
-  if(n3 == 0.0) n3=normal(p15,p[11],p[7],p3,p[4],p[8],p12);
-  if(n3 == 0.0) n3=normal(p12,p[13],p[14],p15,p[2],p[1],p0);
-    
-  GLuint I0,I1,I2,I3;
-    
-  if(c0) {
+  GLuint i0,i1,i2;
+  if(color) {
     GLfloat *c1=c0+4;
     GLfloat *c2=c0+8;
-    GLfloat *c3=c0+12;
     
-    I0=pVertex(p0,n0,c0);
-    I1=pVertex(p12,n1,c1);
-    I2=pVertex(p15,n2,c2);
-    I3=pVertex(p3,n3,c3);
-      
+    i0=data.Vertex(p0,n0,c0);
+    i1=data.Vertex(p6,n1,c1);
+    i2=data.Vertex(p9,n2,c2);
+    
     if(!straight)
-      render(p,I0,I1,I2,I3,p0,p12,p15,p3,false,false,false,false,
-             c0,c1,c2,c3);
+      render(p,i0,i1,i2,p0,p6,p9,false,false,false,c0,c1,c2);
   } else {
-    I0=pvertex(p0,n0);
-    I1=pvertex(p12,n1);
-    I2=pvertex(p15,n2);
-    I3=pvertex(p3,n3);
+    i0=(data.*pvertex)(p0,n0);
+    i1=(data.*pvertex)(p6,n1);
+    i2=(data.*pvertex)(p9,n2);
     
     if(!straight)
-      render(p,I0,I1,I2,I3,p0,p12,p15,p3,false,false,false,false);
+      render(p,i0,i1,i2,p0,p6,p9,false,false,false);
   }
     
   if(straight) {
-    pindices->push_back(I0);
-    pindices->push_back(I1);
-    pindices->push_back(I2);
-    pindices->push_back(I0);
-    pindices->push_back(I2);
-    pindices->push_back(I3);
+    triple P[]={p0,p6,p9};
+    if(!offscreen(3,P)) {
+      std::vector<GLuint> &q=data.indices;
+      q.push_back(i0);
+      q.push_back(i1);
+      q.push_back(i2);
+    }
   }
+  append();
 }
 
 // Use a uniform partition to draw a Bezier triangle.
@@ -601,13 +795,13 @@ void BezierTriangle::render(const triple *p,
                             bool flat0, bool flat1, bool flat2,
                             GLfloat *C0, GLfloat *C1, GLfloat *C2)
 {
-  if(Distance(p) < Res2) { // Triangle is flat
+  if(Distance(p) < res2) { // Bezier triangle is flat
     triple P[]={P0,P1,P2};
     if(!offscreen(3,P)) {
-      std::vector<GLuint> &p=*pindices;
-      p.push_back(I0);
-      p.push_back(I1);
-      p.push_back(I2);
+      std::vector<GLuint> &q=data.indices;
+      q.push_back(I0);
+      q.push_back(I1);
+      q.push_back(I2);
     }
   } else { // Triangle is not flat
     if(offscreen(10,p)) return;
@@ -733,127 +927,87 @@ void BezierTriangle::render(const triple *p,
     // A kludge to remove subdivision cracks, only applied the first time
     // an edge is found to be flat before the rest of the subpatch is.
     
-    triple p0=0.5*(P1+P2);
+    triple m0=0.5*(P1+P2);
     if(!flat0) {
       if((flat0=Straightness(r300,p210,p120,u030) < res2))
-        p0 -= Epsilon*unit(derivative(c[0],c[2],c[5],c[9])+
-                           derivative(c[0],c[1],c[3],c[6]));
-      else p0=r030;
+        m0 -= Epsilon*unit(differential(c[0],c[2],c[5],c[9])+
+                           differential(c[0],c[1],c[3],c[6]));
+      else m0=r030;
     }
 
-    triple p1=0.5*(P2+P0);
+    triple m1=0.5*(P2+P0);
     if(!flat1) {
       if((flat1=Straightness(l003,p012,p021,u030) < res2))
-        p1 -= Epsilon*unit(derivative(c[6],c[3],c[1],c[0])+
-                           derivative(c[6],c[7],c[8],c[9]));
-      else p1=l030;
+        m1 -= Epsilon*unit(differential(c[6],c[3],c[1],c[0])+
+                           differential(c[6],c[7],c[8],c[9]));
+      else m1=l030;
     }
 
-    triple p2=0.5*(P0+P1);
+    triple m2=0.5*(P0+P1);
     if(!flat2) {
       if((flat2=Straightness(l003,p102,p201,r300) < res2))
-        p2 -= Epsilon*unit(derivative(c[9],c[8],c[7],c[6])+
-                           derivative(c[9],c[5],c[2],c[0]));
-      else p2=l300;
+        m2 -= Epsilon*unit(differential(c[9],c[8],c[7],c[6])+
+                           differential(c[9],c[5],c[2],c[0]));
+      else m2=l300;
     }
 
-    if(C0) {
+    if(color) {
       GLfloat c0[4],c1[4],c2[4];
       for(int i=0; i < 4; ++i) {
         c0[i]=0.5*(C1[i]+C2[i]);
-        c1[i]=0.5*(C0[i]+C2[i]);
+        c1[i]=0.5*(C2[i]+C0[i]);
         c2[i]=0.5*(C0[i]+C1[i]);
       }
       
-      GLuint i0=pVertex(p0,n0,c0);
-      GLuint i1=pVertex(p1,n1,c1);
-      GLuint i2=pVertex(p2,n2,c2);
+      GLuint i0=data.Vertex(m0,n0,c0);
+      GLuint i1=data.Vertex(m1,n1,c1);
+      GLuint i2=data.Vertex(m2,n2,c2);
           
-      render(l,I0,i2,i1,P0,p2,p1,false,flat1,flat2,C0,c2,c1);
-      render(r,i2,I1,i0,p2,P1,p0,flat0,false,flat2,c2,C1,c0);
-      render(u,i1,i0,I2,p1,p0,P2,flat0,flat1,false,c1,c0,C2);
-      render(c,i0,i1,i2,p0,p1,p2,false,false,false,c0,c1,c2);
+      render(l,I0,i2,i1,P0,m2,m1,false,flat1,flat2,C0,c2,c1);
+      render(r,i2,I1,i0,m2,P1,m0,flat0,false,flat2,c2,C1,c0);
+      render(u,i1,i0,I2,m1,m0,P2,flat0,flat1,false,c1,c0,C2);
+      render(c,i0,i1,i2,m0,m1,m2,false,false,false,c0,c1,c2);
     } else {
-      GLuint i0=pvertex(p0,n0);
-      GLuint i1=pvertex(p1,n1);
-      GLuint i2=pvertex(p2,n2);
+      GLuint i0=(data.*pvertex)(m0,n0);
+      GLuint i1=(data.*pvertex)(m1,n1);
+      GLuint i2=(data.*pvertex)(m2,n2);
           
-      render(l,I0,i2,i1,P0,p2,p1,false,flat1,flat2);
-      render(r,i2,I1,i0,p2,P1,p0,flat0,false,flat2);
-      render(u,i1,i0,I2,p1,p0,P2,flat0,flat1,false);
-      render(c,i0,i1,i2,p0,p1,p2,false,false,false);
+      render(l,I0,i2,i1,P0,m2,m1,false,flat1,flat2);
+      render(r,i2,I1,i0,m2,P1,m0,flat0,false,flat2);
+      render(u,i1,i0,I2,m1,m0,P2,flat0,flat1,false);
+      render(c,i0,i1,i2,m0,m1,m2,false,false,false);
     }
   }
 }
 
-void BezierTriangle::render(const triple *p, bool straight, GLfloat *c0)
+void transform(const std::vector<VertexData>& b)
 {
-  triple p0=p[0];
-  epsilon=0;
-  for(int i=1; i < 10; ++i)
-    epsilon=max(epsilon,abs2(p[i]-p0));
-  
-  epsilon *= Fuzz2;
-    
-  GLuint I0,I1,I2;
-    
-  triple p6=p[6];
-  triple p9=p[9];
-    
-  triple n0=normal(p9,p[5],p[2],p0,p[1],p[3],p6);
-  triple n1=normal(p0,p[1],p[3],p6,p[7],p[8],p9);    
-  triple n2=normal(p6,p[7],p[8],p9,p[5],p[2],p0);
-    
-  if(c0) {
-    GLfloat *c1=c0+4;
-    GLfloat *c2=c0+8;
-    
-    I0=pVertex(p0,n0,c0);
-    I1=pVertex(p6,n1,c1);
-    I2=pVertex(p9,n2,c2);
-    
-    if(!straight)
-      render(p,I0,I1,I2,p0,p6,p9,false,false,false,c0,c1,c2);
-  } else {
-    I0=pvertex(p0,n0);
-    I1=pvertex(p6,n1);
-    I2=pvertex(p9,n2);
-    
-    if(!straight)
-      render(p,I0,I1,I2,p0,p6,p9,false,false,false);
-  }
-    
-  if(straight) {
-    pindices->push_back(I0);
-    pindices->push_back(I1);
-    pindices->push_back(I2);
-  }
-}
-
-void transform(const std::vector<GLfloat>& b)
-{
-  unsigned n=b.size()/tstride;
+  unsigned n=b.size();
 //  xbuffer.resize(n);
 //  ybuffer.resize(n);
   zbuffer.resize(n);
   
+  double Tz0=gl::dView[2];
+  double Tz1=gl::dView[6];
+  double Tz2=gl::dView[10];
   for(unsigned i=0; i < n; ++i) {
-    unsigned j=tstride*i;
-//    xbuffer[i]=Tx[0]*b[j]+Tx[1]*b[j+1]+Tx[2]*b[j+2];
-//    ybuffer[i]=Ty[0]*b[j]+Ty[1]*b[j+1]+Ty[2]*b[j+2];
-    zbuffer[i]=Tz[0]*b[j]+Tz[1]*b[j+1]+Tz[2]*b[j+2];
+    const GLfloat *v=b[i].position;
+    zbuffer[i]=Tz0*v[0]+Tz1*v[1]+Tz2*v[2];
   }
-  
 }
 
+#if 0
 // precompute min and max bounds of each triangle
 void bounds(const std::vector<GLuint>& I)
 {
   unsigned n=I.size()/3;
+/*  
   xmin.resize(n);
   xmax.resize(n);
   ymin.resize(n);
   ymax.resize(n);
+*/
+  
   zmin.resize(n);
   zmax.resize(n);
   
@@ -863,6 +1017,8 @@ void bounds(const std::vector<GLuint>& I)
     unsigned Ib=I[i3+1];
     unsigned Ic=I[i3+2];
     
+    
+    /*
     double xa=xbuffer[Ia];
     double xb=xbuffer[Ib];
     double xc=xbuffer[Ic];
@@ -870,88 +1026,92 @@ void bounds(const std::vector<GLuint>& I)
     double ya=ybuffer[Ia];
     double yb=ybuffer[Ib];
     double yc=ybuffer[Ic];
+    */
     
     double za=zbuffer[Ia];
     double zb=zbuffer[Ib];
     double zc=zbuffer[Ic];
     
+    /*
     xmin[i]=min(xa,xb,xc);
     xmax[i]=max(xa,xb,xc);
     
     ymin[i]=min(ya,yb,yc);
     ymax[i]=max(ya,yb,yc);
+    */
     
     zmin[i]=min(za,zb,zc);
     zmax[i]=max(za,zb,zc);
   }
 }
+#endif
   
-void BezierPatch::draw()
+void sortTriangles()
 {
-  if(nvertices == 0 && ntvertices == 0 && Nvertices == 0 && Ntvertices == 0)
-    return;
-  
-  const size_t stride=6;
-  const size_t Stride=10;
-  const size_t size=sizeof(GLfloat);
-  const size_t bytestride=stride*size;
-  const size_t Bytestride=Stride*size;
-    
-  glEnableClientState(GL_NORMAL_ARRAY);
-  glEnableClientState(GL_VERTEX_ARRAY);
-  
-  if(nvertices > 0) {
-    glVertexPointer(3,GL_FLOAT,bytestride,&buffer[0]);
-    glNormalPointer(GL_FLOAT,bytestride,&buffer[3]);
-    glDrawElements(GL_TRIANGLES,indices.size(),GL_UNSIGNED_INT,&indices[0]);
-  }
-  
-  if(Nvertices > 0) {
-    glEnableClientState(GL_COLOR_ARRAY);
-    glEnable(GL_COLOR_MATERIAL);
-    glVertexPointer(3,GL_FLOAT,Bytestride,&Buffer[0]);
-    glNormalPointer(GL_FLOAT,Bytestride,&Buffer[3]);
-    glColorPointer(4,GL_FLOAT,Bytestride,&Buffer[6]);
-    glDrawElements(GL_TRIANGLES,Indices.size(),GL_UNSIGNED_INT,&Indices[0]);
-    glDisable(GL_COLOR_MATERIAL);
-    glDisableClientState(GL_COLOR_ARRAY);
-  }
-  
-  if(ntvertices > 0) {
-    tstride=stride;
-    transform(tbuffer); 
-//    bounds(tindices);
-    
-    qsort(&tindices[0],tindices.size()/3,3*sizeof(GLuint),compare);
-      
-    glVertexPointer(3,GL_FLOAT,bytestride,&tbuffer[0]);
-    glNormalPointer(GL_FLOAT,bytestride,&tbuffer[3]);
-    glDrawElements(GL_TRIANGLES,tindices.size(),GL_UNSIGNED_INT,&tindices[0]);
-  }
-  
-  if(Ntvertices > 0) {
-    tstride=Stride;
-    transform(tBuffer);
+  if(!transparentData.indices.empty()) {
+    transform(transparentData.Vertices);
 //    bounds(tIndices);
-    
-    qsort(&tIndices[0],tIndices.size()/3,3*sizeof(GLuint),compare);
-    
-    glEnableClientState(GL_COLOR_ARRAY);
-    glEnable(GL_COLOR_MATERIAL);
-    glVertexPointer(3,GL_FLOAT,Bytestride,&tBuffer[0]);
-    glNormalPointer(GL_FLOAT,Bytestride,&tBuffer[3]);
-    glColorPointer(4,GL_FLOAT,Bytestride,&tBuffer[6]);
-    glDrawElements(GL_TRIANGLES,tIndices.size(),GL_UNSIGNED_INT,&tIndices[0]);
-    glDisable(GL_COLOR_MATERIAL);
-    glDisableClientState(GL_COLOR_ARRAY);
+    qsort(&transparentData.indices[0],transparentData.indices.size()/3,
+          3*sizeof(GLuint),compare);
   }
-  
-  glDisableClientState(GL_VERTEX_ARRAY);
-  glDisableClientState(GL_NORMAL_ARRAY);
-  
-  clear();
 }
 
+void Triangles::queue(size_t nP, const triple* P, size_t nN, const triple* N,
+                      size_t nC, const prc::RGBAColour* C, size_t nI,
+                      const uint32_t (*PP)[3], const uint32_t (*NN)[3],
+                      const uint32_t (*CC)[3], bool Transparent)
+{
+  if(!nN) return;
+  
+  data.clear();
+  Onscreen=true;
+  transparent=Transparent;
+  
+  data.Vertices.resize(nP);
+  data.indices.resize(3*nI);
+  
+  MaterialIndex=nC ? -1-materialIndex : 1+materialIndex; 
+        
+  for(size_t i=0; i < nI; ++i) {
+    const uint32_t *PI=PP[i];
+    uint32_t PI0=PI[0];
+    uint32_t PI1=PI[1];
+    uint32_t PI2=PI[2];
+    triple P0=P[PI0];
+    triple P1=P[PI1];
+    triple P2=P[PI2];
+    const uint32_t *NI=NN[i];
+    if(nC) {
+      const uint32_t *CI=CC[i];
+      prc::RGBAColour C0=C[CI[0]];
+      prc::RGBAColour C1=C[CI[1]];
+      prc::RGBAColour C2=C[CI[2]];
+      GLfloat c0[]={(GLfloat) C0.R,(GLfloat) C0.G,(GLfloat) C0.B,
+                    (GLfloat) C0.A};
+      GLfloat c1[]={(GLfloat) C1.R,(GLfloat) C1.G,(GLfloat) C1.B,
+                    (GLfloat) C1.A};
+      GLfloat c2[]={(GLfloat) C2.R,(GLfloat) C2.G,(GLfloat) C2.B,
+                    (GLfloat) C2.A};
+      transparent |= c0[3]+c1[3]+c2[3] < 765;
+      data.Vertices[PI0]=VertexData(P0,N[NI[0]],c0);
+      data.Vertices[PI1]=VertexData(P1,N[NI[1]],c1);
+      data.Vertices[PI2]=VertexData(P2,N[NI[2]],c2);
+    } else {
+      data.Vertices[PI0]=VertexData(P0,N[NI[0]]);
+      data.Vertices[PI1]=VertexData(P1,N[NI[1]]);
+      data.Vertices[PI2]=VertexData(P2,N[NI[2]]);
+    }
+    triple Q[]={P0,P1,P2};
+    if(!offscreen(3,Q)) {
+      size_t i3=3*i;
+      data.indices[i3]=PI0;
+      data.indices[i3+1]=PI1;
+      data.indices[i3+2]=PI2;
+    }
+  }
+  append();
+}
+ 
 #endif
 
 } //namespace camp
