@@ -22,7 +22,7 @@ This is based on the patch texlive-poppler-0.59.patch <2017-09-19> at
 https://git.archlinux.org/svntogit/packages.git/plain/texlive-bin/trunk
 by Arch Linux. A little modifications are made to avoid a crash for
 some kind of pdf images, such as figure_missing.pdf in gnuplot.
-The poppler should be 0.69.0.
+The poppler should be 0.59.0, ..., 0.68.0.
 POPPLER_VERSION should be defined.
 */
 
@@ -63,6 +63,7 @@ extern "C" {
 #error POPPLER_VERSION should be defined.
 #endif
 #if defined(MIKTEX)
+#undef assert
 #define assert MIKTEX_ASSERT
 #else
 #include <assert.h>
@@ -343,7 +344,7 @@ static void copyFontDict(Object * obj, InObj * r)
     pdf_puts("<<\n");
     assert(r->type == objFont); // FontDescriptor is in fd_tree
     for (i = 0, l = obj->dictGetLength(); i < l; ++i) {
-        key = (char *)obj->dictGetKey(i);
+        key = obj->dictGetKey(i);
         if (strncmp("FontDescriptor", key, strlen("FontDescriptor")) == 0
             || strncmp("BaseFont", key, strlen("BaseFont")) == 0
             || strncmp("Encoding", key, strlen("Encoding")) == 0)
@@ -480,7 +481,7 @@ static void copyFontResources(Object * obj)
     for (i = 0, l = obj->dictGetLength(); i < l; ++i) {
         fontRef = obj->dictGetValNF(i);
         if (fontRef.isRef())
-            copyFont((char *)obj->dictGetKey(i), &fontRef);
+            copyFont(obj->dictGetKey(i), &fontRef);
         else if (fontRef.isDict()) {   // some programs generate pdf with embedded font object
             copyName((char *)obj->dictGetKey(i));
             pdf_puts(" ");
@@ -1003,7 +1004,7 @@ The changes below seem to work fine.
             }
             l = dic1.getLength();
             for (i = 0; i < l; i++) {
-                groupDict.dictAdd((const char *)copyString(dic1.getKey(i)),
+                groupDict.dictAdd(copyString(dic1.getKey(i)),
                                   dic1.getValNF(i));
             }
 // end modification
@@ -1027,13 +1028,13 @@ The changes below seem to work fine.
         pdf_puts("/Resources <<\n");
         for (i = 0, l = obj1->dictGetLength(); i < l; ++i) {
             obj2 = obj1->dictGetVal(i);
-            key = (char *)obj1->dictGetKey(i);
+            key = obj1->dictGetKey(i);
             if (strcmp("Font", key) == 0)
                 copyFontResources(&obj2);
             else if (strcmp("ProcSet", key) == 0)
                 copyProcSet(&obj2);
             else
-                copyOtherResources(&obj2, (char *)key);
+                copyOtherResources(&obj2, key);
         }
         pdf_puts(">>\n");
     }
